# Generated by Django 2.2.9 on 2020-04-07 14:33

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('celeryanalytics', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='celerytaskcompleted',
            name='task',
            field=models.CharField(max_length=500),
        ),
        migrations.AlterField(
            model_name='celerytaskfailed',
            name='task',
            field=models.CharField(max_length=500),
        ),
        migrations.AddIndex(
            model_name='celerytaskcompleted',
            index=models.Index(fields=['task'], name='celeryanaly_task_b60e69_idx'),
        ),
        migrations.AddIndex(
            model_name='celerytaskcompleted',
            index=models.Index(fields=['time'], name='celeryanaly_time_77b42e_idx'),
        ),
        migrations.AddIndex(
            model_name='celerytaskfailed',
            index=models.Index(fields=['task'], name='celeryanaly_task_ae253d_idx'),
        ),
        migrations.AddIndex(
            model_name='celerytaskfailed',
            index=models.Index(fields=['time'], name='celeryanaly_time_bbde51_idx'),
        ),
    ]
