# Generated by Django 3.1.1 on 2021-03-14 01:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('celeryanalytics', '0002_auto_20200407_1433'),
    ]

    operations = [
        migrations.AddField(
            model_name='celerytaskcompleted',
            name='runtime',
            field=models.FloatField(default=0),
        ),
        migrations.AddField(
            model_name='celerytaskfailed',
            name='runtime',
            field=models.FloatField(default=0),
        ),
    ]
